@@ -44,8 +44,7 @@ class __TwigTemplate_55f91962626a7a309a423fa01c946f55 extends Template
 <html>
 ";
         // line 3
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
-array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz")), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
         // line 7
         yield "
     <body class=\"header-fixed\">
@@ -139,70 +138,15 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         }
         // line 59
         yield "            </script>
-            <script>
-                (function () {
-                    // prevent double-install (avoids breaking pages)
-                    if (window.__causeBuzzTitlePatchInstalled) return;
-                    window.__causeBuzzTitlePatchInstalled = true;
-
-                    const BRAND = 'Cause Buzz';
-
-                    function normalizeTitle() {
-                        try {
-                            let t = (document.title || '').trim();
-
-                            // remove trailing \"| Mautic\"
-                            t = t.replace(/\\s*\\|\\s*Mautic\\s*\$/i, '').trim();
-
-                            // if title is empty or exactly \"Mautic\", just use the brand
-                            if (!t || /^Mautic\$/i.test(t)) {
-                                document.title = BRAND;
-                                return;
-                            }
-
-                            // avoid \"Cause Buzz | Cause Buzz\"
-                            if (new RegExp('^' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\\\\|\\\\s*' + BRAND + '\$', 'i').test(t)) {
-                                document.title = BRAND;
-                                return;
-                            }
-
-                            // avoid double appends
-                            if (new RegExp('\\\\|\\\\s*' + BRAND.replace(/[.*+?^\${}()|[\\]\\\\]/g, '\\\\\$&') + '\\\\s*\$', 'i').test(t)) {
-                                document.title = t;
-                                return;
-                            }
-
-                            document.title = t + ' | ' + BRAND;
-                        } catch (e) {
-                            // swallow errors so we never break the UI
-                        }
-                    }
-
-                    function scheduleNormalize() {
-                        // run after Mautic has finished its SPA title update
-                        setTimeout(normalizeTitle, 0);
-                    }
-
-                    // first load
-                    if (document.readyState === 'loading') {
-                        document.addEventListener('DOMContentLoaded', scheduleNormalize, { once: true });
-                    } else {
-                        scheduleNormalize();
-                    }
-
-                    // SPA navigation hook
-                    document.addEventListener('mautic:page:load', scheduleNormalize);
-                })();
-            </script>
 
             ";
-        // line 116
+        // line 61
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 117
+        // line 62
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 120
+        // line 65
         yield "
         </section>
     </body>
@@ -248,7 +192,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  223 => 40,  216 => 39,  206 => 120,  204 => 117,  200 => 116,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  167 => 40,  160 => 39,  150 => 65,  148 => 62,  144 => 61,  140 => 59,  126 => 47,  124 => 46,  118 => 42,  116 => 39,  106 => 32,  102 => 31,  92 => 24,  85 => 20,  79 => 17,  75 => 16,  71 => 15,  67 => 14,  63 => 13,  59 => 12,  54 => 10,  49 => 7,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
