@@ -280,6 +280,6 @@ class __TwigTemplate_26d93afdec163d18b413c597c5ca6993 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Timeline/_list.html.twig", "/var/www/html/staging-demo/app/bundles/LeadBundle/Resources/views/Timeline/_list.html.twig");
+        return new Source("", "@MauticLead/Timeline/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Timeline/_list.html.twig");
     }
 }
