@@ -81,32 +81,28 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
         $macros = $this->macros;
         // line 8
         yield "    <div class=\"toolbar\">
-        ";
-        // line 9
-        if ($this->extensions['Mautic\CoreBundle\Twig\Extension\SecurityExtension']->isGranted("focus:focus:edit")) {
-            // line 10
-            yield "            <a href=\"";
-            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_focus_edit", ["id" => CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 10, $this->source); })()), "id", [], "any", false, false, false, 10)]), "html", null, true);
-            yield "\"
-               class=\"btn btn-primary btn-nospin\">
-                <i class=\"ri-edit-line\"></i>
-                ";
-            // line 13
-            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.core.form.edit"), "html", null, true);
-            yield "
-            </a>
-        ";
-        }
-        // line 16
-        yield "
         <a href=\"";
-        // line 17
+        // line 9
+        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_focus_action", ["objectAction" => "edit", "objectId" => CoreExtension::getAttribute($this->env, $this->source,         // line 11
+(isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 11, $this->source); })()), "id", [], "any", false, false, false, 11)]), "html", null, true);
+        // line 12
+        yield "\"
+           class=\"btn btn-primary btn-nospin\">
+            <i class=\"ri-edit-line\"></i>
+            ";
+        // line 15
+        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.core.form.edit"), "html", null, true);
+        yield "
+        </a>
+
+        <a href=\"";
+        // line 18
         yield $this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getPath("mautic_focus_index");
         yield "\"
            class=\"btn btn-default btn-nospin\">
             <i class=\"ri-close-line\"></i>
             ";
-        // line 20
+        // line 21
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.core.form.close"), "html", null, true);
         yield "
         </a>
@@ -115,14 +111,14 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
         yield from [];
     }
 
-    // line 25
+    // line 27
     /**
      * @return iterable<null|scalar|\Stringable>
      */
     public function block_content(array $context, array $blocks = []): iterable
     {
         $macros = $this->macros;
-        // line 26
+        // line 28
         yield "  ";
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->includeScript("plugins/MauticFocusBundle/Assets/js/focus.js");
         yield "
@@ -136,14 +132,14 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
                   <div class=\"box-layout\">
                       <div class=\"col-xs-10\">
                           <div class=\"text-muted\">";
-        // line 36
-        yield $this->env->getRuntime('Exercise\HTMLPurifierBundle\Twig\HTMLPurifierRuntime')->purify(CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 36, $this->source); })()), "description", [], "any", false, false, false, 36));
+        // line 38
+        yield $this->env->getRuntime('Exercise\HTMLPurifierBundle\Twig\HTMLPurifierRuntime')->purify(CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 38, $this->source); })()), "description", [], "any", false, false, false, 38));
         yield "</div>
                       </div>
                       <div class=\"col-xs-2 text-right\">
                           ";
-        // line 39
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/publishstatus_badge.html.twig", ["entity" => (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 39, $this->source); })())]);
+        // line 41
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/publishstatus_badge.html.twig", ["entity" => (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 41, $this->source); })())]);
         yield "
                       </div>
                   </div>
@@ -157,13 +153,13 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
                           <table class=\"table table-hover mb-0\">
                               <tbody>
                               ";
-        // line 51
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/details.html.twig", ["entity" => (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 51, $this->source); })())]);
+        // line 53
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/details.html.twig", ["entity" => (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 53, $this->source); })())]);
         yield "
                               <tr>
                                   <td width=\"20%\">
                                       <span class=\"fw-b\">";
-        // line 54
+        // line 56
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.focus.details.views"), "html", null, true);
         yield "</span>
                                   </td>
@@ -174,7 +170,7 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
                               <tr>
                                   <td width=\"20%\">
                                       <span class=\"fw-b\">";
-        // line 62
+        // line 64
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.focus.details.unique_views"), "html", null, true);
         yield "</span>
                                   </td>
@@ -194,12 +190,12 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
               <!-- form detail collapseable toggler -->
               <div class=\"hr-expand nm\">
                   <span data-toggle=\"tooltip\" title=\"";
-        // line 79
+        // line 81
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.core.details"), "html", null, true);
         yield "\">
                       <a href=\"javascript:void(0)\" class=\"arrow text-muted collapsed\" data-toggle=\"collapse\" data-target=\"#focus-details\"><span class=\"caret\"></span>
                         ";
-        // line 81
+        // line 83
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.core.details"), "html", null, true);
         yield "
                       </a>
@@ -217,22 +213,22 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
                                       <h5 class=\"text-white dark-md fw-sb mb-xs\">
                                           <span class=\"fa fa-line-chart\"></span>
                                           ";
-        // line 96
+        // line 98
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.focus.graph.stats"), "html", null, true);
         yield "
                                       </h5>
                                   </div>
                                   <div class=\"col-xs-8 va-m\">
                                       ";
-        // line 100
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/graph_dateselect.html.twig", ["dateRangeForm" => (isset($context["dateRangeForm"]) || array_key_exists("dateRangeForm", $context) ? $context["dateRangeForm"] : (function () { throw new RuntimeError('Variable "dateRangeForm" does not exist.', 100, $this->source); })()), "class" => "pull-right"]);
+        // line 102
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/graph_dateselect.html.twig", ["dateRangeForm" => (isset($context["dateRangeForm"]) || array_key_exists("dateRangeForm", $context) ? $context["dateRangeForm"] : (function () { throw new RuntimeError('Variable "dateRangeForm" does not exist.', 102, $this->source); })()), "class" => "pull-right"]);
         yield "
                                   </div>
                               </div>
                               <div class=\"pt-0 pl-15 pb-10 pr-15\">
                                   ";
-        // line 104
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/chart.html.twig", ["chartData" => (isset($context["stats"]) || array_key_exists("stats", $context) ? $context["stats"] : (function () { throw new RuntimeError('Variable "stats" does not exist.', 104, $this->source); })()), "chartType" => "line", "chartHeight" => 300]);
+        // line 106
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/chart.html.twig", ["chartData" => (isset($context["stats"]) || array_key_exists("stats", $context) ? $context["stats"] : (function () { throw new RuntimeError('Variable "stats" does not exist.', 106, $this->source); })()), "chartType" => "line", "chartHeight" => 300]);
         yield "
                               </div>
                           </div>
@@ -242,20 +238,20 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
               <!--/ stats -->
 
               ";
-        // line 112
+        // line 114
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ContentExtension']->getCustomContent("details.stats.graph.below", $context);
         yield "
 
               ";
-        // line 114
-        if ((array_key_exists("trackables", $context) &&  !Twig\Extension\CoreExtension::testEmpty((isset($context["trackables"]) || array_key_exists("trackables", $context) ? $context["trackables"] : (function () { throw new RuntimeError('Variable "trackables" does not exist.', 114, $this->source); })())))) {
-            // line 115
+        // line 116
+        if ((array_key_exists("trackables", $context) &&  !Twig\Extension\CoreExtension::testEmpty((isset($context["trackables"]) || array_key_exists("trackables", $context) ? $context["trackables"] : (function () { throw new RuntimeError('Variable "trackables" does not exist.', 116, $this->source); })())))) {
+            // line 117
             yield "                  <!-- tabs controls -->
                   <ul class=\"nav nav-tabs pr-md pl-md\">
                       <li class=\"active\">
                           <a href=\"#clicks-container\" role=\"tab\" data-toggle=\"tab\">
                               ";
-            // line 119
+            // line 121
             yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.trackable.click_counts"), "html", null, true);
             yield "
                           </a>
@@ -267,18 +263,18 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
                   <div class=\"tab-content pa-md\">
                       <div class=\"tab-pane active bdr-w-0\" id=\"clicks-container\">
                           ";
-            // line 128
-            yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticPage/Trackable/click_counts.html.twig", ["trackables" =>             // line 129
-(isset($context["trackables"]) || array_key_exists("trackables", $context) ? $context["trackables"] : (function () { throw new RuntimeError('Variable "trackables" does not exist.', 129, $this->source); })()), "entity" =>             // line 130
-(isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 130, $this->source); })()), "channel" => "focus"]);
-            // line 132
+            // line 130
+            yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticPage/Trackable/click_counts.html.twig", ["trackables" =>             // line 131
+(isset($context["trackables"]) || array_key_exists("trackables", $context) ? $context["trackables"] : (function () { throw new RuntimeError('Variable "trackables" does not exist.', 131, $this->source); })()), "entity" =>             // line 132
+(isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 132, $this->source); })()), "channel" => "focus"]);
+            // line 134
             yield "
                       </div>
                   </div>
                   <!-- end: tab-content -->
               ";
         }
-        // line 137
+        // line 139
         yield "
           </div>
       </div>
@@ -291,16 +287,16 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
               <div class=\"panel bg-info bg-light-lg bdr-w-0 mb-0\">
                   <div class=\"panel-body\">
                       <h5 class=\"fw-sb mb-sm\">";
-        // line 148
+        // line 150
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.focus.install.header"), "html", null, true);
         yield "</h5>
                       <p class=\"mb-sm\">";
-        // line 149
+        // line 151
         yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\TranslationExtension']->trans("mautic.focus.install.description"), "html", null, true);
         yield "</p>
                       <input onclick=\"this.setSelectionRange(0, this.value.length);\" type=\"text\" class=\"form-control\" readonly value=\"&lt;script src=&quot;";
-        // line 150
-        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getUrl("mautic_focus_generate", ["id" => CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 150, $this->source); })()), "id", [], "any", false, false, false, 150)], true), "html", null, true);
+        // line 152
+        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape($this->extensions['Symfony\Bridge\Twig\Extension\RoutingExtension']->getUrl("mautic_focus_generate", ["id" => CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 152, $this->source); })()), "id", [], "any", false, false, false, 152)], true), "html", null, true);
         yield "&quot; type=&quot;text/javascript&quot; charset=&quot;utf-8&quot; async=&quot;async&quot;&gt;&lt;/script&gt;\"/>
                   </div>
               </div>
@@ -310,12 +306,12 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
           <hr class=\"hr-w-2\" style=\"width:50%\">
 
           ";
-        // line 159
+        // line 161
         yield "          <div class=\"panel bg-transparent shd-none bdr-rds-0 bdr-w-0 mb-0\">
               <!-- recent activity -->
               ";
-        // line 161
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/recentactivity.html.twig", ["logs" => (isset($context["logs"]) || array_key_exists("logs", $context) ? $context["logs"] : (function () { throw new RuntimeError('Variable "logs" does not exist.', 161, $this->source); })())]);
+        // line 163
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/recentactivity.html.twig", ["logs" => (isset($context["logs"]) || array_key_exists("logs", $context) ? $context["logs"] : (function () { throw new RuntimeError('Variable "logs" does not exist.', 163, $this->source); })())]);
         yield "
           </div>
       </div>
@@ -324,8 +320,8 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
   <!--/ end: box layout -->
 
   <input type=\"hidden\" name=\"entityId\" id=\"entityId\" value=\"";
-        // line 168
-        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 168, $this->source); })()), "id", [], "any", false, false, false, 168), "html", null, true);
+        // line 170
+        yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape(CoreExtension::getAttribute($this->env, $this->source, (isset($context["item"]) || array_key_exists("item", $context) ? $context["item"] : (function () { throw new RuntimeError('Variable "item" does not exist.', 170, $this->source); })()), "id", [], "any", false, false, false, 170), "html", null, true);
         yield "\"/>
 ";
         yield from [];
@@ -352,7 +348,7 @@ class __TwigTemplate_ac9c770e5c1789fcef4a22ba8a67feec extends Template
      */
     public function getDebugInfo(): array
     {
-        return array (  328 => 168,  318 => 161,  314 => 159,  303 => 150,  299 => 149,  295 => 148,  282 => 137,  275 => 132,  273 => 130,  272 => 129,  271 => 128,  259 => 119,  253 => 115,  251 => 114,  246 => 112,  235 => 104,  228 => 100,  221 => 96,  203 => 81,  198 => 79,  178 => 62,  167 => 54,  161 => 51,  146 => 39,  140 => 36,  126 => 26,  119 => 25,  110 => 20,  104 => 17,  101 => 16,  95 => 13,  88 => 10,  86 => 9,  83 => 8,  76 => 7,  65 => 5,  54 => 3,  43 => 1,);
+        return array (  324 => 170,  314 => 163,  310 => 161,  299 => 152,  295 => 151,  291 => 150,  278 => 139,  271 => 134,  269 => 132,  268 => 131,  267 => 130,  255 => 121,  249 => 117,  247 => 116,  242 => 114,  231 => 106,  224 => 102,  217 => 98,  199 => 83,  194 => 81,  174 => 64,  163 => 56,  157 => 53,  142 => 41,  136 => 38,  122 => 28,  115 => 27,  106 => 21,  100 => 18,  94 => 15,  89 => 12,  87 => 11,  86 => 9,  83 => 8,  76 => 7,  65 => 5,  54 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
