@@ -42,10 +42,9 @@ class __TwigTemplate_ccc3f72ab858d105a4306f762fae357a extends Template
         // line 1
         yield "<!DOCTYPE html>
 <html>
-    ";
+";
         // line 3
-        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? (        $this->unwrap()->renderBlock("headerTitle", $context, $blocks)) : (((        // line 4
-array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::default((isset($context["headerTitle"]) || array_key_exists("headerTitle", $context) ? $context["headerTitle"] : (function () { throw new RuntimeError('Variable "headerTitle" does not exist.', 4, $this->source); })()), "")) : ("")))), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
+        yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Default/head.html.twig", ["headerTitle" => ((        $this->unwrap()->hasBlock("headerTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz")), "pageTitle" => ((        $this->unwrap()->hasBlock("pageTitle", $context, $blocks)) ? ("Cause Buzz") : ("Cause Buzz"))]);
         // line 7
         yield "
     <body class=\"header-fixed\">
@@ -139,64 +138,15 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         }
         // line 59
         yield "            </script>
-            <script>
-                (function() {
-                    const BRAND = 'Cause Buzz';
-
-                    function applyTitle() {
-                        let t = document.title.trim();
-
-                        // If Mautic sets \"Something | Mautic\", replace that part
-                        if (t.endsWith('| Mautic')) {
-                            t = t.replace(/\\|\\s*Mautic\$/, '| ' + BRAND);
-                            document.title = t;
-                            return;
-                        }
-
-                        // If the page only sets \"Mautic\" with no prefix
-                        if (t === 'Mautic') {
-                            document.title = BRAND;
-                            return;
-                        }
-
-                        // If no brand yet, append it
-                        if (!t.includes(BRAND)) {
-                            document.title = t + ' | ' + BRAND;
-                        }
-                    }
-
-                    // Run immediately
-                    applyTitle();
-
-                    // Watch for SPA title changes
-                    const titleEl = document.querySelector('title');
-                    if (titleEl) {
-                        new MutationObserver(applyTitle).observe(titleEl, { childList: true });
-                    }
-
-                    // Hook into Mautic's SPA navigation
-                    if (window.Mautic && typeof window.Mautic.onPageLoad === 'function') {
-                        const original = window.Mautic.onPageLoad;
-                        window.Mautic.onPageLoad = function(e) {
-                            original(e);
-                            applyTitle();
-                        };
-                    }
-
-                    // Stimulus events also change title in Mautic 5
-                    document.addEventListener('stimulus:load', applyTitle);
-
-                })();
-            </script>
 
             ";
-        // line 110
+        // line 61
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 111
+        // line 62
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 114
+        // line 65
         yield "
         </section>
     </body>
@@ -242,7 +192,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  217 => 40,  210 => 39,  200 => 114,  198 => 111,  194 => 110,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  167 => 40,  160 => 39,  150 => 65,  148 => 62,  144 => 61,  140 => 59,  126 => 47,  124 => 46,  118 => 42,  116 => 39,  106 => 32,  102 => 31,  92 => 24,  85 => 20,  79 => 17,  75 => 16,  71 => 15,  67 => 14,  63 => 13,  59 => 12,  54 => 10,  49 => 7,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
